@@ -1,27 +1,27 @@
 # Copyrights 1995-2007 by Mark Overmeer <perl@overmeer.net>.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.02.
+# Pod stripped from pm file by OODoc 1.03.
 use strict;
 
 package Mail::Mailer::testfile;
 use vars '$VERSION';
-$VERSION = '2.00_03';
+$VERSION = '2.01';
 use base 'Mail::Mailer::rfc822';
 
 use Mail::Util qw/mailaddress/;
 
-our %config = (outfile => 'mailer.testfile');
 my $num = 0;
-
-sub can_cc { 0 }
+sub can_cc() { 0 }
 
 sub exec($$$)
 {   my ($self, $exe, $args, $to) = @_;
 
-    open F, '>>', $Mail::Mailer::testfile::config{outfile};
-    print F "\n===\ntest ", ++$num, " ",
-            (scalar localtime),
+    my $outfn = $Mail::Mailer::testfile::config{outfile} || 'mailer.testfile';
+    open F, '>>', $outfn
+        or die "Cannot append message to testfile $outfn: $!";
+
+    print F "\n===\ntest ", ++$num, " ", (scalar localtime),
             "\nfrom: " . mailaddress(),
             "\nto: " . join(' ',@{$to}), "\n\n";
     close F;
@@ -35,7 +35,7 @@ sub close { 1 }
 
 package Mail::Mailer::testfile::pipe;
 use vars '$VERSION';
-$VERSION = '2.00_03';
+$VERSION = '2.01';
 
 sub TIEHANDLE
 {   my ($class, $self) = @_;
